@@ -21,9 +21,13 @@ getHUCName <- function(lon, lat, dataset='WBDHU10-ms', HUCs=NULL, allData=FALSE)
     stop('Missing database. Please loadSpatialData("',dataset,'")',call.=FALSE)
   }
   # check if longitude and latitude falls in the right range
-  if ( min(lon)< -180 || max(lon) > 180 || min(lat) < -90 || max(lat) > 90 ) {
-    stop('Longitude or latitude is not specified in the correct range -180:180, -90:90',call.=FALSE)
-  }  
+  if ( min(lon, na.rm=TRUE) < -180 || 
+       max(lon, na.rm=TRUE) > 180 || 
+       min(lat, na.rm=TRUE) < -90 || 
+       max(lat, na.rm=TRUE) > 90 ) {
+    stop('Longitude or latitude is not specified in the correct range. Please try again.')
+  }
+
   # Use standard internal name (assumes pre-loaded dataset)
   SPDF <- get(dataset) 
   
